diff --git a/selfdrive/debug/print_docs_diff.py b/selfdrive/debug/print_docs_diff.py
index 469ceb8fe9..b7721ca3a5 100755
--- a/selfdrive/debug/print_docs_diff.py
+++ b/selfdrive/debug/print_docs_diff.py
@@ -83,7 +83,7 @@ def print_car_info_diff(path):
for new_car, base_car in car_changes:
# Tier changes
if base_car.tier != new_car.tier:
- changes["tier"].append(f"- Tier for {base_car.make} {base_car.name} changed! ({base_car.tier.name.title()} {ARROW_SYMBOL} {new_car.tier.name.title()})")
+ changes["tier"].append(f"- Tier for {base_car.name} changed! ({base_car.tier.name.title()} {ARROW_SYMBOL} {new_car.tier.name.title()})")
# Column changes
row_diff = build_column_diff(base_car, new_car)
@@ -92,11 +92,11 @@ def print_car_info_diff(path):
# Detail sentence changes
if base_car.detail_sentence != new_car.detail_sentence:
- changes["detail"].append(f"- Sentence for {base_car.make} {base_car.name} changed!\n" +
+ changes["detail"].append(f"- Sentence for {base_car.name} changed!\n" +
" ```diff\n" +
- f" + {base_car.detail_sentence}\n" +
- f" - {new_car.detail_sentence}\n" +
- "```")
+ f" - {base_car.detail_sentence}\n" +
+ f" + {new_car.detail_sentence}\n" +
+ " ```")
# Print diff
if any(len(c) for c in changes.values()):
diff --git a/selfdrive/car/docs_definitions.py b/selfdrive/car/docs_definitions.py
index c305a2eeec..21df85030f 100644
--- a/selfdrive/car/docs_definitions.py
+++ b/selfdrive/car/docs_definitions.py
@@ -147,11 +147,12 @@ class CarInfo:
else:
alc = ""
- # Exception for Nissan and Subaru which do not auto-resume yet
- if CP.carName not in ("nissan", "subaru"):
- acc = f" while driving above {self.min_enable_speed * CV.MS_TO_MPH:.0f} mph" if self.min_enable_speed > 0 else " that automatically resumes from a stop"
- else:
- acc = ""
+ # Exception for Nissan, Subaru, and stock long Toyota which do not auto-resume yet
+ acc = ""
+ if self.min_enable_speed > 0:
+ acc = f" while driving above {self.min_enable_speed * CV.MS_TO_MPH:.0f} mph"
+ elif CP.carName not in ("nissan", "subaru", "toyota") or (CP.carName == "toyota" and CP.openpilotLongitudinalControl):
+ acc = " that automatically resumes from a stop"
if self.row[Column.STEERING_TORQUE] != Star.FULL:
sentence_builder += " This car may not be able to take tight turns on its own."